@@ -27,8 +27,14 @@
 #'   passed on to [emmeans::summary.emmGrid()] or [lsmeans::summary.ref.grid()].
 #'
 #' @examples
+#' 
+#' # feel free to ignore the following line—it allows {broom} to supply 
+#' # examples without requiring the model-supplying package to be installed.
+#' if (requireNamespace("emmeans", quietly = TRUE)) {
 #'
+#' # load libraries for models and data
 #' library(emmeans)
+#' 
 #' # linear model for sales of oranges per day
 #' oranges_lm1 <- lm(sales1 ~ price1 + price2 + day + store, data = oranges)
 #'
@@ -47,6 +53,7 @@
 #'
 #' # plot confidence intervals
 #' library(ggplot2)
+#' 
 #' ggplot(tidy(marginal, conf.int = TRUE), aes(day, estimate)) +
 #'   geom_point() +
 #'   geom_errorbar(aes(ymin = conf.low, ymax = conf.high))
@@ -59,7 +66,9 @@
 #'     day = c("2", "3", "4")
 #'   )
 #' )
+#' 
 #' by_price
+#' 
 #' tidy(by_price)
 #'
 #' ggplot(tidy(by_price, conf.int = TRUE), aes(price2, estimate, color = day)) +
@@ -68,6 +77,9 @@
 #'
 #' # joint_tests
 #' tidy(joint_tests(oranges_lm1))
+#' 
+#' }
+#' 
 #' @aliases emmeans_tidiers
 #' @export
 #' @family emmeans tidiers
@@ -186,7 +198,10 @@ tidy_emmeans_summary <- function(x, null.value = NULL, term_names = NULL) {
     "effect.size" = "estimate",
     "SE" = "std.error",
     "lower.CL" = "conf.low",
+    "asymp.LCL" = "conf.low",
     "upper.CL" = "conf.high",
+    "asymp.UCL" = "conf.high",
+    "z.ratio" = "statistic",
     "t.ratio" = "statistic",
     "F.ratio" = "statistic",
     "df1" = "num.df",
@@ -208,18 +223,13 @@ tidy_emmeans_summary <- function(x, null.value = NULL, term_names = NULL) {
 
   colnames(ret) <- dplyr::recode(colnames(ret), !!!(repl))
 
-  # Remove std.error if conf.low/high exist
-  if (any(c("conf.low", "conf.high") %in% colnames(ret))) {
-    ret <- select(ret, -std.error)
-  }
-
   # If contrast column exists, add null.value column
   if ("contrast" %in% colnames(ret)) {
     if (length(null.value) < nrow(ret)) null.value <- rep_len(null.value, nrow(ret))
     ret <- bind_cols(contrast = ret[, "contrast"], null.value = null.value, select(ret, -contrast))
   }
 
-  # Add term column, if appropriate, unless it exists
+  # add term column, if appropriate, unless it exists
   if ("term" %in% colnames(ret)) {
     ret <- ret %>%
       mutate(term = stringr::str_trim(term))
