@@ -27,32 +27,38 @@
 #'
 #' @examples
 #' 
+#' # feel free to ignore the following line—it allows {broom} to supply 
+#' # examples without requiring the model-supplying package to be installed.
 #' if (requireNamespace("fixest", quietly = TRUE)) {
 #' 
-#' \donttest{
+#' # load libraries for models and data
 #' library(fixest)
 #' 
-#' gravity <- feols(log(Euros) ~ log(dist_km) | Origin + Destination + Product + Year, trade)
+#' gravity <- 
+#'   feols(
+#'     log(Euros) ~ log(dist_km) | Origin + Destination + Product + Year, trade
+#'   )
 #'
 #' tidy(gravity)
 #' glance(gravity)
 #' augment(gravity, trade)
 #'
-#' ## To get robust or clustered SEs, users can either:
-#' # 1) Or, specify the arguments directly in the tidy() call
+#' # to get robust or clustered SEs, users can either:
+#' 
+#' # 1) specify the arguments directly in the `tidy()` call
 #' 
 #' tidy(gravity, conf.int = TRUE, cluster = c("Product", "Year"))
 #' 
 #' tidy(gravity, conf.int = TRUE, se = "threeway")
 #' 
-#' # 2) Feed tidy() a summary.fixest object that has already accepted these arguments
+#' # 2) or, feed tidy() a summary.fixest object that has already accepted 
+#' # these arguments
 #' 
 #' gravity_summ <- summary(gravity, cluster = c("Product", "Year"))
+#' 
 #' tidy(gravity_summ, conf.int = TRUE)
 #' 
-#' # Approach (1) is preferred.
-#' 
-#' }
+#' # approach (1) is preferred.
 #' 
 #' }
 #'
@@ -162,13 +168,16 @@ glance.fixest <- function(x, ...) {
   )
 
   if (identical(x$method, "feols")) {
-    r2_vals <- fixest::r2(x, type = c("r2", "ar2", "wr2"))
+    r2_types <- c("r2", "ar2", "wr2")
+    r2_vals <- purrr::map_dbl(r2_types, fixest::r2, x = x) %>%
+      purrr::set_names(r2_types)
     r2_names <- c("r.squared", "adj.r.squared", "within.r.squared")
     # Pull the summary objects that are specific to OLS
     res_specific <- with(
       summary(x, ...),
       tibble(
-        sigma = sqrt(sigma2),
+        # catch error in models with only fixed effects and no regressors
+        sigma = tryCatch(sqrt(sigma2), error = function(e) NA_real_),
         pseudo.r.squared = NA_real_, # always NA for OLS
       )
     )
