@@ -4,24 +4,30 @@
 #' @param x A `fitdistr` object returned by [MASS::fitdistr()].
 #' @template param_unused_dots
 #'
-#' @return A [tibble::tibble] with one row for estimated parameter, with
-#'   columns:
-#'   
-#'   \item{term}{The term that was estimated}
-#'   \item{estimate}{Estimated value}
-#'   \item{std.error}{Standard error of estimate}
-#'   
-#' @examples
+#' @evalRd return_tidy("term", "estimate", "std.error")
 #'
+#' @examples
+#' 
+#' # feel free to ignore the following line—it allows {broom} to supply 
+#' # examples without requiring the model-supplying package to be installed.
+#' if (requireNamespace("MASS", quietly = TRUE)) {
+#'
+#' # load libraries for models and data
+#' library(MASS)
+#'
+#' # generate data
 #' set.seed(2015)
 #' x <- rnorm(100, 5, 2)
 #'
-#' library(MASS)
+#' #  fit models
 #' fit <- fitdistr(x, dnorm, list(mean = 3, sd = 1))
 #'
+#' # summarize model fit with tidiers
 #' tidy(fit)
 #' glance(fit)
-#'
+#' 
+#' }
+#' 
 #' @export
 #' @family fitdistr tidiers
 #' @aliases fitdistr_tidiers
@@ -37,18 +43,21 @@ tidy.fitdistr <- function(x, ...) {
 
 #' @templateVar class fitdistr
 #' @template title_desc_glance
-#' 
-#' @inheritParams tidy.fitdistr
 #'
-#' @return A one-row [tibble::tibble] with columns:
-#'   \item{n}{Number of observations used in estimation}
-#'   \item{logLik}{log-likelihood of estimated data}
-#'   \item{AIC}{Akaike Information Criterion}
-#'   \item{BIC}{Bayesian Information Criterion}
+#' @inherit tidy.fitdistr params examples
+#'
+#' @evalRd return_glance("logLik", "AIC", "BIC", "nobs")
 #'
 #' @export
 #' @family fitdistr tidiers
 #' @seealso [tidy()], [MASS::fitdistr()]
 glance.fitdistr <- function(x, ...) {
-  finish_glance(data.frame(n = x$n), x)
+  as_glance_tibble(
+    logLik = stats::logLik(x),
+    AIC = stats::AIC(x),
+    BIC = stats::BIC(x),
+    nobs = stats::nobs(x),
+    na_types = "rrri"
+  )
+  
 }
