@@ -21,6 +21,44 @@
 #' @export
 #' @seealso [tidy()], [quantreg::rq()]
 #' @family quantreg tidiers
+#' 
+#' @examples 
+#' 
+#' # feel free to ignore the following line—it allows {broom} to supply 
+#' # examples without requiring the model-supplying package to be installed.
+#' if (requireNamespace("quantreg", quietly = TRUE)) {
+#' 
+#' # load modeling library and data
+#' library(quantreg)
+#' 
+#' data(stackloss)
+#' 
+#' # median (l1) regression fit for the stackloss data. 
+#' mod1 <- rq(stack.loss ~ stack.x, .5)  
+#' 
+#' # weighted sample median
+#' mod2 <- rq(rnorm(50) ~ 1, weights = runif(50))
+#' 
+#' # summarize model fit with tidiers
+#' tidy(mod1)
+#' glance(mod1)
+#' augment(mod1)
+#' 
+#' tidy(mod2)
+#' glance(mod2)
+#' augment(mod2)
+#' 
+#' # varying tau to generate an rqs object
+#' mod3 <- rq(stack.loss ~ stack.x, tau = c(.25, .5))
+#' 
+#' tidy(mod3)
+#' augment(mod3)
+#' 
+#' # glance cannot handle rqs objects like `mod3`--use a purrr 
+#' # `map`-based workflow instead
+#' 
+#' }
+#' 
 tidy.rq <- function(x, se.type = NULL, conf.int = FALSE,
                     conf.level = 0.95, ...) {
 
@@ -99,7 +137,7 @@ glance.rq <- function(x, ...) {
 #'
 #' @details Depending on the arguments passed on to `predict.rq` via `...`,
 #'   a confidence interval is also calculated on the fitted values resulting in
-#'   columns `.conf.low` and `.conf.high`. Does not provide confidence
+#'   columns `.lower` and `.upper`. Does not provide confidence
 #'   intervals when data is specified via the `newdata` argument.
 #'
 #' @export
@@ -129,7 +167,7 @@ augment.rq <- function(x, data = model.frame(x), newdata = NULL, ...) {
     original[[".tau"]] <- x[["tau"]]
     return(as_tibble(original))
   } else {
-    colnames(pred) <- c(".fitted", ".conf.low", ".conf.high")
+    colnames(pred) <- c(".fitted", ".lower", ".upper")
     original[[".tau"]] <- x[["tau"]]
     return(as_tibble(cbind(original, pred)))
   }
