@@ -9,10 +9,17 @@
 #'
 #' @examples
 #' 
+#' # feel free to ignore the following line—it allows {broom} to supply 
+#' # examples without requiring the model-supplying package to be installed.
 #' if (requireNamespace("speedglm", quietly = TRUE)) {
 #'
-#' mod <- speedglm::speedlm(mpg ~ wt + qsec, data = mtcars, fitted = TRUE)
+#' # load modeling library
+#' library(speedglm)
 #'
+#' # fit model
+#' mod <- speedlm(mpg ~ wt + qsec, data = mtcars, fitted = TRUE)
+#'
+#' # summarize model fit with tidiers
 #' tidy(mod)
 #' glance(mod)
 #' augment(mod)
@@ -31,7 +38,7 @@ tidy.speedlm <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
   # summary(x)$coefficients misses rank deficient rows (i.e. coefs that
   # summary.lm() sets to NA), catch them here and add them back
   coefs <- tibble::enframe(stats::coef(x), name = "term", value = "estimate")
-  ret <- left_join(coefs, ret)
+  ret <- left_join(coefs, ret, by = c("term", "estimate"))
 
   if (conf.int) {
     ci <- broom_confint_terms(x, level = conf.level)
