@@ -28,8 +28,8 @@
 #'   geom_vline(xintercept = 0, lty = 4) +
 #'   geom_errorbarh()
 #'   
-#' # Aside: There are tidy() and glance() methods for lm.summary objects too. 
-#' # This can be useful when you want to conserve memory by converting large lm 
+#' # aside: There are tidy() and glance() methods for lm.summary objects too. 
+#' # this can be useful when you want to conserve memory by converting large lm 
 #' # objects into their leaner summary.lm equivalents.
 #' s <- summary(mod)
 #' tidy(s, conf.int = TRUE)
@@ -45,7 +45,9 @@
 #' augment(mod, newdata = newdata)
 #' 
 #' # ggplot2 example where we also construct 95% prediction interval
-#' mod2 <- lm(mpg ~ wt, data = mtcars) ## simpler bivariate model since we're plotting in 2D
+#' 
+#' # simpler bivariate model since we're plotting in 2D
+#' mod2 <- lm(mpg ~ wt, data = mtcars) 
 #' 
 #' au <- augment(mod2, newdata = newdata, interval = "prediction")
 #' 
@@ -57,6 +59,7 @@
 #' # predict on new data without outcome variable. Output does not include .resid
 #' newdata <- newdata %>%
 #'   select(-mpg)
+#'   
 #' augment(mod, newdata = newdata)
 #'
 #' au <- augment(mod, data = mtcars)
@@ -68,6 +71,7 @@
 #'   geom_smooth(se = FALSE)
 #'
 #' plot(mod, which = 6)
+#' 
 #' ggplot(au, aes(.hat, .cooksd)) +
 #'   geom_vline(xintercept = 0, colour = NA) +
 #'   geom_abline(slope = seq(0, 3, by = 0.5), colour = "white") +
@@ -78,14 +82,16 @@
 #' a <- matrix(rnorm(20), nrow = 10)
 #' b <- a + rnorm(length(a))
 #' result <- lm(b ~ a)
+#' 
 #' tidy(result)
+#' 
 #' @aliases lm_tidiers
 #' @export
 #' @seealso [tidy()], [stats::summary.lm()]
 #' @family lm tidiers
 tidy.lm <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
 
-  warn_on_subclass(x)
+  warn_on_subclass(x, "tidy")
 
   ret <- as_tibble(summary(x)$coefficients, rownames = "term")
   colnames(ret) <- c("term", "estimate", "std.error", "statistic", "p.value")
@@ -137,7 +143,7 @@ tidy.lm <- function(x, conf.int = FALSE, conf.level = 0.95, ...) {
 augment.lm <- function(x, data = model.frame(x), newdata = NULL,
                        se_fit = FALSE, interval =  c("none", "confidence", "prediction"), ...) {
   
-  warn_on_subclass(x)
+  warn_on_subclass(x, "augment")
   
   interval <- match.arg(interval)
   df <- augment_newdata(x, data, newdata, se_fit, interval)
@@ -184,7 +190,7 @@ augment.lm <- function(x, data = model.frame(x), newdata = NULL,
 #' @family lm tidiers
 glance.lm <- function(x, ...) {
   
-  warn_on_subclass(x)
+  warn_on_subclass(x, "glance")
   
   # check whether the model was fitted with only an intercept, in which
   # case drop the fstatistic related columns
