@@ -35,25 +35,31 @@
 #'   components in the original space. The columns are:
 #'
 #'   \item{`row`}{The variable labels (colnames) of the data set on
-#'   which PCA was performed}
-#'   \item{`PC`}{An integer vector indicating the principal component}
+#'   which PCA was performed.}
+#'   \item{`PC`}{An integer vector indicating the principal component.}
 #'   \item{`value`}{The value of the eigenvector (axis score) on the
-#'   indicated principal component}
+#'   indicated principal component.}
 #'
 #'   If `matrix` is `"d"`, `"eigenvalues"` or `"pcs"`, the columns are:
 #'
-#'   \item{`PC`}{An integer vector indicating the principal component}
-#'   \item{`std.dev`}{Standard deviation explained by this PC}
-#'   \item{`percent`}{Fraction of variation explained by this component}
+#'   \item{`PC`}{An integer vector indicating the principal component.}
+#'   \item{`std.dev`}{Standard deviation explained by this PC.}
+#'   \item{`percent`}{Fraction of variation explained by this component
+#'     (a numeric value between 0 and 1).}
 #'   \item{`cumulative`}{Cumulative fraction of variation explained by
-#'     principle components up to this component.}
+#'     principle components up to this component (a numeric value between 0 and
+#'     1).}
 #'
 #' @details See https://stats.stackexchange.com/questions/134282/relationship-between-svd-and-pca-how-to-use-svd-to-perform-pca
 #'   for information on how to interpret the various tidied matrices. Note
 #'   that SVD is only equivalent to PCA on centered data.
 #'
 #' @examples
-#'
+#' 
+#' # feel free to ignore the following line—it allows {broom} to supply 
+#' # examples without requiring the data-supplying package to be installed.
+#' if (requireNamespace("maps", quietly = TRUE)) {
+#' 
 #' pc <- prcomp(USArrests, scale = TRUE)
 #'
 #' # information about rotation
@@ -68,6 +74,7 @@
 #' # state map
 #' library(dplyr)
 #' library(ggplot2)
+#' library(maps)
 #'
 #' pc %>%
 #'   tidy(matrix = "samples") %>%
@@ -80,11 +87,15 @@
 #'   ggtitle("Principal components of arrest data")
 #'
 #' au <- augment(pc, data = USArrests)
+#' 
 #' au
 #'
 #' ggplot(au, aes(.fittedPC1, .fittedPC2)) +
 #'   geom_point() +
 #'   geom_text(aes(label = .rownames), vjust = 1, hjust = 1)
+#'   
+#' }   
+#'   
 #' @aliases prcomp_tidiers
 #' @export
 #' @seealso [stats::prcomp()], [svd_tidiers]
@@ -108,41 +119,22 @@ tidy.prcomp <- function(x, matrix = "u", ...) {
       new_column = "PC"
     )
   } else if (matrix %in% c("rotation", "variables", "v", "loadings")) {
-    labels <- if (is.null(rownames(x$rotation))) {
-      1:nrow(x$rotation)
-    } else {
-      rownames(x$rotation)
-    }
-    variables <- tidyr::pivot_longer(as.data.frame(x$rotation),
-      cols = dplyr::everything(),
-      names_to = "key",
-      values_to = "value"
-    ) %>%
-      tibble::remove_rownames() %>%
-      as.data.frame()
-    ret <- data.frame(
-      label = rep(labels, times = ncomp),
-      variables,
-      stringsAsFactors = FALSE
-    )
-    names(ret) <- c("column", "PC", "value")
+    ret <- x$rotation %>% 
+      tibble::as_tibble(rownames = "column") %>% 
+      tidyr::pivot_longer(cols = -"column", 
+                          names_to = "PC", 
+                          values_to = "value")
+    if (is.null(rownames(x$rotation))) ret$column <- as.integer(ret$column)
   } else if (matrix %in% c("x", "samples", "u", "scores")) {
-    labels <- if (is.null(rownames(x$x))) 1:nrow(x$x) else rownames(x$x)
-    samples <- tidyr::pivot_longer(as.data.frame(x$x),
-      cols = dplyr::everything(),
-      names_to = "key",
-      values_to = "value"
-    ) %>%
-      tibble::remove_rownames() %>%
-      as.data.frame()
-    ret <- data.frame(
-      label = rep(labels, times = ncomp),
-      samples
-    )
-    names(ret) <- c("row", "PC", "value")
+    ret <- x$x %>% 
+      tibble::as_tibble(rownames = "row") %>% 
+      tidyr::pivot_longer(cols = -"row", 
+                          names_to = "PC", 
+                          values_to = "value")
+    if (is.null(rownames(x$x))) ret$row <- as.integer(ret$row)
   }
 
-  ## change the PC to a numeric
+  # change the PC to a numeric
   ret <- mutate(ret, PC = as.numeric(stringr::str_replace(PC, "PC", "")))
   as_tibble(ret)
 }
