@@ -7,18 +7,24 @@
 #' @evalRd return_tidy("index", "series", "value")
 #'
 #' @examples
+#' 
+#' # feel free to ignore the following line—it allows {broom} to supply 
+#' # examples without requiring the model-supplying package to be installed.
+#' if (requireNamespace("zoo", quietly = TRUE)) {
 #'
+#' # load libraries for models and data
 #' library(zoo)
 #' library(ggplot2)
 #'
 #' set.seed(1071)
 #'
-#' # data generated as shown in the zoo vignette
+#' # generate data
 #' Z.index <- as.Date(sample(12450:12500, 10))
 #' Z.data <- matrix(rnorm(30), ncol = 3)
 #' colnames(Z.data) <- c("Aa", "Bb", "Cc")
 #' Z <- zoo(Z.data, Z.index)
 #'
+#' # summarize model fit with tidiers + visualization
 #' tidy(Z)
 #'
 #' ggplot(tidy(Z), aes(index, value, color = series)) +
@@ -31,17 +37,27 @@
 #' Zrolled <- rollmean(Z, 5)
 #' ggplot(tidy(Zrolled), aes(index, value, color = series)) +
 #'   geom_line()
+#'   
+#' }
+#'   
 #' @aliases zoo_tidiers
 #' @export
 #' @seealso [tidy()], [zoo::zoo()]
 #' @family time series tidiers
 tidy.zoo <- function(x, ...) {
-  ret <- data.frame(as.matrix(x), index = zoo::index(x))
-  ret <- tibble::as_tibble(ret)
-  colnames(ret)[1:ncol(x)] <- colnames(x)
-  pivot_longer(ret,
-    cols = c(dplyr::everything(), -index),
-    names_to = "series",
-    values_to = "value"
-  )
+  # check for univariate zoo series
+  if (length(dim(x)) > 0) {
+    ret <- data.frame(as.matrix(x), index = zoo::index(x))
+    ret <- tibble::as_tibble(ret)
+    colnames(ret)[1:ncol(x)] <- colnames(x)
+    out <- pivot_longer(ret,
+                        cols = c(dplyr::everything(), -index),
+                        names_to = "series",
+                        values_to = "value"
+    )
+  } else {
+    out <- tibble::tibble(index = zoo::index(x),
+                          value = zoo::coredata(x))
+  }
+  return(out)
 }
