@@ -30,6 +30,12 @@ test_that("fixest tidier arguments", {
   check_arguments(augment.fixest)
 })
 
+test_that("bug #1018: fixed effects but no regressors", {
+    mod <- fixest::feols(Sepal.Length ~ 1 | Species, data = iris)
+    check_tidy_output(tidy(mod))
+    check_glance_outputs(glance(mod))
+})
+
 test_that("tidy.fixest", {
   td <- tidy(fit)
   td2 <- tidy(fit2, conf.int = TRUE)
@@ -80,8 +86,11 @@ test_that("augment.fixest", {
 })
 
 test_that("all other fixest estimators run", {
+  skip_on_cran()
+  skip_on_ci()
+  
   form <- v2 ~ v4 | id
-  res_feglm    <- fixest::feglm(form,    data = df)
+  res_feglm    <- fixest::feglm(form,    data = df, family = 'gaussian')
   res_fenegbin <- fixest::fenegbin(form, data = df)
   res_feNmlm   <- fixest::feNmlm(form,   data = df)
   res_femlm    <- fixest::femlm(form,    data = df)
@@ -103,7 +112,7 @@ test_that("all other fixest estimators run", {
     glance(res_fepois)
   )
 
-  # Augment
+  # augment
   # Note this this causes warnings with strict=TRUE because
   # modeltests:::acceptable_augment_colnames calls model.frame, which doesn't
   # work for fixest models.
@@ -130,6 +139,9 @@ test_that("all other fixest estimators run", {
 
 
 test_that("tidiers work with model results or summary of model results", {
+  skip_on_cran()
+  skip_on_ci()
+  
   # Default standard errors are clustered by `id`. Test against non-default
   # independent, heteroskedastic ("hetero") standard errors.
   fit2_summ <- summary(fit2, se = "hetero")
@@ -142,7 +154,7 @@ test_that("tidiers work with model results or summary of model results", {
   expect_equal(augment(fit2, df, se = "hetero"), augment(fit2_summ, df))
 
   # Repeat for feglm
-  res_glm <- fixest::feglm(v2 ~ v4 | id, data = df)
+  res_glm <- fixest::feglm(v2 ~ v4 | id, data = df, family = 'gaussian')
   res_glm_summ <- summary(fixest::feglm(v2 ~ v4 | id, data = df), se = "hetero")
   expect_equal(tidy(res_glm, se = "hetero"), tidy(res_glm_summ))
   expect_equal(
